%doppler vs. time intensity (DTI) script for the Xband CW radar
%Gregory L. Charvat

clear all;
close all;

%read the raw data .wave file here
load doppler_xband_cw.mat;

%constants
c = 3E8; %(m/s) speed of light

%radar parameters
Tp = 0.1; %(s) pulse time
FS = 200E3; %(Hz)
N = Tp*FS; %# of samples per pulse
fc = 10.20E9; %(Hz) Center frequency (connected VCO Vtune to +5)

%creat doppler vs. time plot data set here
for ii = 1:round(size(s,2)/N)-1
    sif(ii,:) = s(1+(ii-1)*N:ii*N);
end

%subtract the average DC term here
sif = sif - mean(s);

zpad = 8*N/2;

%apply hamming window to data
h = hamming(size(sif,2));
for ii = 1:size(sif,1)
    sif(ii,:) = h.*sif(ii,:)';
end

%doppler vs. time plot:
v = dbv(ifft(sif,zpad,2));
v = v(:,1:size(v,2)/2);
mmax = max(max(v));
%calculate velocity
delta_f = linspace(0, FS/2, size(v,2)); %(Hz)
lambda=c/fc;
velocity = delta_f*lambda/2;
%calculate time
time = linspace(1,Tp*size(v,1),size(v,1)); %(sec)
%plot
imagesc(velocity,time,v-mmax,[-80, 0]);
colorbar;
xlim([0 40]); %limit velocity axis
xlabel('Velocity (m/sec)');
ylabel('time (sec)');

%listen to the results!
%sound(s(882000:size(s,1),:)', 44100, 16)
